/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * info-containers HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : info-containers.h
 * CREATION DATE : Nov 18, 2021
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef SRC_INFO_CONTAINERS_H_
#define SRC_INFO_CONTAINERS_H_

/** @ingroup storageinfo
 * @defgroup info-containers Information Containers
 * Provides the definitions of different information containers
 */

#include <nmapp/types/nm-types.h>

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/


/** Configuration of Reliable Writing, i.e. at a power failure during write operation, the device protects existing data */
typedef union
{
    struct
    {
        uint8_t isSetPartition1 : 1;   // 0x01: partition 1
        uint8_t isSetPartition2 : 1;   // 0x02: partition 2
        uint8_t isSetPartition3 : 1;   // 0x04: partition 3
        uint8_t isSetPartition4 : 1;   // 0x08: partition 4
        uint8_t isSetPartition5 : 1;   // 0x10: partition 5
        uint8_t isSetRest       : 3;   // rest
    };
    uint8_t flags;
} ReliableWriteFlags_t;


/** MMC estimated life time in percent */
typedef struct
{
    int8_t percentUsedSlc;
    int8_t percentUsedMlc;
} Lifetime_t;



/** Container containing static storage information */
typedef struct
{
    const char*           mmcChipName;
    const char*           mmcHwRevision;
    const char*           mmcRevision;
    const char*           mmcFwVersion;
    const char*           mmcSerialNbr;
    bool                  isReliablyWritable;
    ReliableWriteFlags_t  reliableWriteConfig;
} StaticInfo_t;


/** Container containing dynamic storage information */
typedef struct
{
    int8_t       preEolValue;
    const char*  preEolString;
    Lifetime_t   lifeTime;
    float64_t    freeDiskSpaceMB;
} DynamicInfo_t;




/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/



#ifdef __cplusplus
}
#endif

#endif /* SRC_INFO_CONTAINERS_H_ */
