/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland
 * -------------------------------------------------------------------------------------------
 *
 * storage-info MODULE
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : storage-info.c
 * CREATION DATE : Nov 23, 2021
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/

#include <nmapp/exception/exception.h>
#include <nmapp/sys/assertion.h>
#include "storage-info.h"

/*********************************************************************************************
 *        LOCALS
 *********************************************************************************************/

//--------------------------------------------------------------------------------------------
void getAndwriteDynamicInfoToFile(StorageInfoRef me)
{
    DynamicInfo_t* dynamicInfoRef = InfoCollector_getDynamicInfo(me->infoCollector);
    InfoWriter_writeDynamicInfoToFile(me->infoWriter, dynamicInfoRef);
    ILog_msg(me->sysLogRef, LOG_LEVEL_DBG, "dynamic info updated");
}

/*********************************************************************************************
 *        GLOBALS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
void StorageInfo_onIntervalTimeout(void* calleCtx)
{
    StorageInfoRef me = (StorageInfoRef)calleCtx;
    assert(me != NULL);

    ILog_msg(me->sysLogRef, LOG_LEVEL_DBG, "Interval timer timed out -> updating dynamic info...");
    EvtLoop_stopTimer(me->intervalTimer);

    getAndwriteDynamicInfoToFile(me);

    // Restart timer if periodic
    if(EvtLoop_isTimerPeriodic(me->intervalTimer))
    {
        EvtLoop_startTimer(me->intervalTimer);
    }

}
//--------------------------------------------------------------------------------------------
void StorageInfo_init(StorageInfoRef me)
{
    assert(me != NULL);
    StaticInfo_t*  staticInfoRef  = InfoCollector_getStaticInfo(me->infoCollector);
    InfoWriter_writeStaticInfoToFile(me->infoWriter, staticInfoRef);
    getAndwriteDynamicInfoToFile(me);
}
//--------------------------------------------------------------------------------------------
/** @brief Destroy Storage Information
 * Destroys the storage-info instance.
 *
 * @param me            A reference to my instance
 */
void StorageInfo_destroy(StorageInfoRef me)
{
    if(me != NULL)
    {
        EvtLoop_stopTimer(me->intervalTimer);
        EvtLoop_destroyTimer(me->intervalTimer);

        InfoWriter_destroy(me->infoWriter);
        InfoCollector_destroy(me->infoCollector);
    }
}
