/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * InfoCollector HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : InfoCollector.h
 * CREATION DATE : Oct 25, 2021
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef SRC_INFOCOLLECTOR_H_
#define SRC_INFOCOLLECTOR_H_

/** @ingroup storageinfo
 * @defgroup infoCollector Information Collector
 * This module provides a collector of (mmc) storage information (static and dynamic).
 */

#include <nmapp/types/nm-types.h>
#include <nmapp/logging/ILog.h>
#include <nmapp/file/IFileOperation.h>
#include <nmapp/sys/system.h>
#include "info-containers.h"
#include "StorageDetector.h"

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

typedef struct __InfoCollectorPrivate * InfoCollectorRef;


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @brief Create Information Collector
 * Creates an instance of information collector
 *
 * @param logRef              A reference to the logger to use
 * @param storageDetectorRef  A reference to the storage detector
 * @param fileOpRef           A reference to the file operation interface to use
 * @return A reference to the created instance
 */
InfoCollectorRef InfoCollector_create(ILogRef logRef, StorageDetectorRef storageDetectorRef, IFileOperationRef fileOpRef);
//--------------------------------------------------------------------------------------------
/** @brief Destroy Information Collector
 * Destroys an instance of information collector
 *
 * @param me     A reference to my instance
 */
void InfoCollector_destroy(InfoCollectorRef me);
//--------------------------------------------------------------------------------------------
/** @brief Get Static Information
 * Returns a reference to the container containing the static information
 *
 * @param me     A reference to my instance
 * @return A pointer to the staticInfo container
 */
StaticInfo_t* InfoCollector_getStaticInfo(InfoCollectorRef me);
//--------------------------------------------------------------------------------------------
/** @brief Get Dynamic Information
 * Returns a reference to the container containing the dynamic information
 *
 * @param me     A reference to my instance
 * @return A pointer to the dynamicInfo container
 */
DynamicInfo_t* InfoCollector_getDynamicInfo(InfoCollectorRef me);


#ifdef __cplusplus
}
#endif

#endif /* SRC_INFOCOLLECTOR_H_ */
