/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland
 * -------------------------------------------------------------------------------------------
 *
 * InfoWriter HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : InfoWriter.h
 * CREATION DATE : Nov 18, 2021
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef SRC_INFOWRITER_H_
#define SRC_INFOWRITER_H_

/** @ingroup storageinfo
 * @defgroup InfoWriter Information Writer
 * This module provides a writer of the (mmc) storage information (static and dynamic).
 */

#include <nmapp/types/nm-types.h>
#include <nmapp/logging/ILog.h>
#include "info-containers.h"

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

typedef struct __InfoWriterPrivate * InfoWriterRef;


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @brief Create Information Writer
 * Creates an instance of information writer
 *
 * @param logRef              A reference to the logger to use
 * @param fileOpRef           A reference to the file operation interface to use
 * @param file                A reference to the target file (pathname) to write
 * @return A reference to the created instance
 */
InfoWriterRef InfoWriter_create(ILogRef logRef, IFileOperationRef fileOpRef, const char* file);
//--------------------------------------------------------------------------------------------
/** @brief Destroy Information Writer
 * Destroys an instance of information writer
 *
 * @param me     A reference to my instance
 */
void InfoWriter_destroy(InfoWriterRef me);
//--------------------------------------------------------------------------------------------
/** @brief Write Static Information To File
 * Writes static information to file
 *
 * @param me           A reference to my instance
 * @param pStaticInfo  A pointer to the static information container
 */
void InfoWriter_writeStaticInfoToFile(InfoWriterRef me, StaticInfo_t* pStaticInfo);
//--------------------------------------------------------------------------------------------
/** @brief Write Dynamic Information To File
 * Writes dynamic information to file
 *
 * @param me            A reference to my instance
 * @param pDynamicInfo  A pointer to the dynamic information container
 */
void InfoWriter_writeDynamicInfoToFile(InfoWriterRef me, DynamicInfo_t* pDynamicInfo);



#ifdef __cplusplus
}
#endif

#endif /* SRC_INFOWRITER_H_ */
