/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland
 * -------------------------------------------------------------------------------------------
 *
 * storage-detector HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : storage-detector.h
 * CREATION DATE : Oct 28, 2021
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef SRC_STORAGEDETECTOR_H_
#define SRC_STORAGEDETECTOR_H_

/** @ingroup storageinfo
 * @defgroup storage-detector Storage Detector
 * Provides functions to get the mmc device.
 */

#include <nmapp/types/nm-types.h>
#include <nmapp/logging/ILog.h>

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

typedef struct __StorageDetector * StorageDetectorRef;


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @brief Create a Storage Detector Instance
 * Creates an instance of storage detector.
 *
 * @param logRef    A reference to the logger to use
 * @return The reference to the created instance
 */
StorageDetectorRef StorageDetector_create(ILogRef logRef);
//--------------------------------------------------------------------------------------------
/** @brief Destroy a Storage Detector Instance
 * Destroys an instance of storage detector.
 *
 * @param me        A reference to my instance
 */
void StorageDetector_destroy(StorageDetectorRef me);
//--------------------------------------------------------------------------------------------
/** @brief Init a Storage Detector Instance
 * Inits an instance of storage detector.
 *
 * @param me        A reference to my instance
 */
void StorageDetector_init(StorageDetectorRef me);
//--------------------------------------------------------------------------------------------
/** @brief Get MMC Device
 * Returns the path to the mmc device running on storage0
 *
 * @param me        A reference to the my instance
 * @return The path to the mmc device of storage0
 */
const char* StorageDetector_getMmcDevice(StorageDetectorRef me);
//--------------------------------------------------------------------------------------------
/** @brief Get MMC Device Info Path
 * Returns the path to the mmc device information running on storage0
 *
 * @param me        A reference to the my instance
 * @return The path to the mmc device information of storage0
 */
const char* StorageDetector_getMmcDeviceInfoPath(StorageDetectorRef me);


#ifdef __cplusplus
}
#endif

#endif /* SRC_STORAGEDETECTOR_H_ */
