/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland
 * -------------------------------------------------------------------------------------------
 *
 * storage-info HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : storage-info.h
 * CREATION DATE : Nov 18, 2021
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef SRC_STORAGE_INFO_H_
#define SRC_STORAGE_INFO_H_

/**
 * @defgroup storageinfo storage-info
 * This application writes storage information to the file system which can be used by list-devices.
 */

#include <nmapp/types/nm-types.h>
#include <nmapp/logging/SysLogger.h>
#include <nmapp/event/evt-loop.h>
#include "InfoCollector.h"
#include "InfoWriter.h"

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

typedef struct __StorageInfoPrivate * StorageInfoRef;

typedef struct __StorageInfoPrivate
{
    const char*        appName;
    SysLoggerRef       sysLogger;
    ILogRef            sysLogRef;
    EvtLoopTimerRef    intervalTimer;
    InfoCollectorRef   infoCollector;
    InfoWriterRef      infoWriter;
} StorageInfoPrivate_t;


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @brief On Interval Timeout
 * Is called when the interval timer times out to get the latest dynamic
 * data and store them to file.
 *
 * @param calleCtx            A reference to the calle context, aka me
 */
void StorageInfo_onIntervalTimeout(void* calleCtx);
//--------------------------------------------------------------------------------------------
/** @brief Initialize Storage Information
 * Initializes the storage-info instance.
 *
 * @param me            A reference to my instance
 */
void StorageInfo_init(StorageInfoRef me);
//--------------------------------------------------------------------------------------------
/** @brief Destroy Storage Information
 * Destroys the storage-info instance.
 *
 * @param me            A reference to my instance
 */
void StorageInfo_destroy(StorageInfoRef me);


#ifdef __cplusplus
}
#endif

#endif /* SRC_STORAGE_INFO_H_ */
